@@ -39,7 +39,7 @@ impl Core {
                 self.handle_our_elders_agreement(section_auth, sig).await
             }
             Proposal::JoinsAllowed(joins_allowed) => {
-                self.joins_allowed = joins_allowed;
+                *self.joins_allowed.write().await = joins_allowed;
                 Ok(vec![])
             }
         }
